.. Pyzgoubi documentation master file, created by
   sphinx-quickstart on Fri Sep  2 17:42:44 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to PyZgoubi's documentation!
====================================

Contents:

.. toctree::
   :maxdepth: 2

   install
   doc
   api


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

